pub struct Identity {
pub keypair: Keypair,
pub peer_id: PeerId,
}Fields
keypair: KeypairLong-term Ed25519 identity keypair.
peer_id: PeerIdStable peer identifier derived from the public key.
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn generate_from_keypair(keypair: Keypair) -> Self
pub fn generate_from_keypair(keypair: Keypair) -> Self
Wrap an existing keypair and derive its peer id.
Sourcepub fn default_path() -> Result<PathBuf, CoreError>
pub fn default_path() -> Result<PathBuf, CoreError>
Default on-disk identity path on native targets.
Sourcepub fn load(path: Option<&Path>) -> Result<Self, CoreError>
pub fn load(path: Option<&Path>) -> Result<Self, CoreError>
Load an identity from disk or return a detailed error.